# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from freeclimb.configuration import Configuration


class MutableResourceModel(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'uri': 'str',
        'date_created': 'str',
        'date_updated': 'str',
        'revision': 'int'
    }

    attribute_map = {
        'uri': 'uri',
        'date_created': 'dateCreated',
        'date_updated': 'dateUpdated',
        'revision': 'revision'
    }

    def __init__(self, uri=None, date_created=None, date_updated=None, revision=None, local_vars_configuration=None):  # noqa: E501
        """MutableResourceModel - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._uri = None
        self._date_created = None
        self._date_updated = None
        self._revision = None
        self.discriminator = None

        if uri is not None:
            self.uri = uri
        if date_created is not None:
            self.date_created = date_created
        if date_updated is not None:
            self.date_updated = date_updated
        if revision is not None:
            self.revision = revision

    @property
    def uri(self):
        """Gets the uri of this MutableResourceModel.  # noqa: E501

        The URI for this resource, relative to /apiserver.  # noqa: E501

        :return: The uri of this MutableResourceModel.  # noqa: E501
        :rtype: str
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        """Sets the uri of this MutableResourceModel.

        The URI for this resource, relative to /apiserver.  # noqa: E501

        :param uri: The uri of this MutableResourceModel.  # noqa: E501
        :type: str
        """

        self._uri = uri

    @property
    def date_created(self):
        """Gets the date_created of this MutableResourceModel.  # noqa: E501

        The date that this resource was created (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT).  # noqa: E501

        :return: The date_created of this MutableResourceModel.  # noqa: E501
        :rtype: str
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this MutableResourceModel.

        The date that this resource was created (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT).  # noqa: E501

        :param date_created: The date_created of this MutableResourceModel.  # noqa: E501
        :type: str
        """

        self._date_created = date_created

    @property
    def date_updated(self):
        """Gets the date_updated of this MutableResourceModel.  # noqa: E501

        The date that this resource was last updated (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT).  # noqa: E501

        :return: The date_updated of this MutableResourceModel.  # noqa: E501
        :rtype: str
        """
        return self._date_updated

    @date_updated.setter
    def date_updated(self, date_updated):
        """Sets the date_updated of this MutableResourceModel.

        The date that this resource was last updated (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT).  # noqa: E501

        :param date_updated: The date_updated of this MutableResourceModel.  # noqa: E501
        :type: str
        """

        self._date_updated = date_updated

    @property
    def revision(self):
        """Gets the revision of this MutableResourceModel.  # noqa: E501

        Revision count for the resource. This count is set to 1 on creation and is incremented every time it is updated.  # noqa: E501

        :return: The revision of this MutableResourceModel.  # noqa: E501
        :rtype: int
        """
        return self._revision

    @revision.setter
    def revision(self, revision):
        """Sets the revision of this MutableResourceModel.

        Revision count for the resource. This count is set to 1 on creation and is incremented every time it is updated.  # noqa: E501

        :param revision: The revision of this MutableResourceModel.  # noqa: E501
        :type: int
        """

        self._revision = revision

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.to_camel_case(attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif value is None:
                continue
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MutableResourceModel):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MutableResourceModel):
            return True

        return self.to_dict() != other.to_dict()

    def to_camel_case(self, snake_str):
        components = snake_str.split('_')
        return components[0] + ''.join(x.title() for x in components[1:])



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from freeclimb.configuration import Configuration


class FilterLogsRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'pql': 'str'
    }

    attribute_map = {
        'pql': 'pql'
    }

    def __init__(self, pql=None, local_vars_configuration=None):  # noqa: E501
        """FilterLogsRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._pql = None
        self.discriminator = None

        self.pql = pql

    @property
    def pql(self):
        """Gets the pql of this FilterLogsRequest.  # noqa: E501

        The filter query for retrieving logs. See **Performance Query Language** below.  # noqa: E501

        :return: The pql of this FilterLogsRequest.  # noqa: E501
        :rtype: str
        """
        return self._pql

    @pql.setter
    def pql(self, pql):
        """Sets the pql of this FilterLogsRequest.

        The filter query for retrieving logs. See **Performance Query Language** below.  # noqa: E501

        :param pql: The pql of this FilterLogsRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and pql is None:  # noqa: E501
            raise ValueError("Invalid value for `pql`, must not be `None`")  # noqa: E501

        self._pql = pql

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.to_camel_case(attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif value is None:
                continue
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FilterLogsRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FilterLogsRequest):
            return True

        return self.to_dict() != other.to_dict()

    def to_camel_case(self, snake_str):
        components = snake_str.split('_')
        return components[0] + ''.join(x.title() for x in components[1:])



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from freeclimb.configuration import Configuration


class Play(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'file': 'str',
        'loop': 'int',
        'conference_id': 'str',
        'privacy_mode': 'bool'
    }

    attribute_map = {
        'file': 'file',
        'loop': 'loop',
        'conference_id': 'conferenceId',
        'privacy_mode': 'privacyMode'
    }

    def __init__(self, file=None, loop=None, conference_id=None, privacy_mode=None, local_vars_configuration=None):  # noqa: E501
        """Play - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._file = None
        self._loop = None
        self._conference_id = None
        self._privacy_mode = None
        self.discriminator = None

        self.file = file
        if loop is not None:
            self.loop = loop
        if conference_id is not None:
            self.conference_id = conference_id
        if privacy_mode is not None:
            self.privacy_mode = privacy_mode

    @property
    def file(self):
        """Gets the file of this Play.  # noqa: E501

        RL of the audio file to be played to the caller. The URL can be the `recordingUrl` generated from the `RecordUtterance` or `StartRecordCall` PerCL commands.   # noqa: E501

        :return: The file of this Play.  # noqa: E501
        :rtype: str
        """
        return self._file

    @file.setter
    def file(self, file):
        """Sets the file of this Play.

        RL of the audio file to be played to the caller. The URL can be the `recordingUrl` generated from the `RecordUtterance` or `StartRecordCall` PerCL commands.   # noqa: E501

        :param file: The file of this Play.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and file is None:  # noqa: E501
            raise ValueError("Invalid value for `file`, must not be `None`")  # noqa: E501

        self._file = file

    @property
    def loop(self):
        """Gets the loop of this Play.  # noqa: E501

        Number of times the audio file is played. Specifying '0' causes the Play action to loop until the Call is hung up.  # noqa: E501

        :return: The loop of this Play.  # noqa: E501
        :rtype: int
        """
        return self._loop

    @loop.setter
    def loop(self, loop):
        """Sets the loop of this Play.

        Number of times the audio file is played. Specifying '0' causes the Play action to loop until the Call is hung up.  # noqa: E501

        :param loop: The loop of this Play.  # noqa: E501
        :type: int
        """

        self._loop = loop

    @property
    def conference_id(self):
        """Gets the conference_id of this Play.  # noqa: E501

        ID of the Conference the audio should be rendered to. If this is not specified, the audio is by default rendered to the caller associated with the call leg that corresponds to the current PerCL execution context. The call leg associated with this command must be in the specified Conference or the command will return an error.  # noqa: E501

        :return: The conference_id of this Play.  # noqa: E501
        :rtype: str
        """
        return self._conference_id

    @conference_id.setter
    def conference_id(self, conference_id):
        """Sets the conference_id of this Play.

        ID of the Conference the audio should be rendered to. If this is not specified, the audio is by default rendered to the caller associated with the call leg that corresponds to the current PerCL execution context. The call leg associated with this command must be in the specified Conference or the command will return an error.  # noqa: E501

        :param conference_id: The conference_id of this Play.  # noqa: E501
        :type: str
        """

        self._conference_id = conference_id

    @property
    def privacy_mode(self):
        """Gets the privacy_mode of this Play.  # noqa: E501

        Parameter `privacyMode` will not log the `text` as required by PCI compliance.  # noqa: E501

        :return: The privacy_mode of this Play.  # noqa: E501
        :rtype: bool
        """
        return self._privacy_mode

    @privacy_mode.setter
    def privacy_mode(self, privacy_mode):
        """Sets the privacy_mode of this Play.

        Parameter `privacyMode` will not log the `text` as required by PCI compliance.  # noqa: E501

        :param privacy_mode: The privacy_mode of this Play.  # noqa: E501
        :type: bool
        """

        self._privacy_mode = privacy_mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.to_camel_case(attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif value is None:
                continue
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Play):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Play):
            return True

        return self.to_dict() != other.to_dict()

    def to_camel_case(self, snake_str):
        components = snake_str.split('_')
        return components[0] + ''.join(x.title() for x in components[1:])



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from freeclimb.configuration import Configuration


class SendDigits(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'digits': 'str',
        'pause_ms': 'int',
        'privacy_mode': 'bool'
    }

    attribute_map = {
        'digits': 'digits',
        'pause_ms': 'pauseMs',
        'privacy_mode': 'privacyMode'
    }

    def __init__(self, digits=None, pause_ms=None, privacy_mode=None, local_vars_configuration=None):  # noqa: E501
        """SendDigits - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._digits = None
        self._pause_ms = None
        self._privacy_mode = None
        self.discriminator = None

        self.digits = digits
        if pause_ms is not None:
            self.pause_ms = pause_ms
        if privacy_mode is not None:
            self.privacy_mode = privacy_mode

    @property
    def digits(self):
        """Gets the digits of this SendDigits.  # noqa: E501

        String containing the digits to be played. The string cannot be empty and can include any digit, plus `#`, or `*`, and allows embedding specification for delay or pause between the output of individual digits.  # noqa: E501

        :return: The digits of this SendDigits.  # noqa: E501
        :rtype: str
        """
        return self._digits

    @digits.setter
    def digits(self, digits):
        """Sets the digits of this SendDigits.

        String containing the digits to be played. The string cannot be empty and can include any digit, plus `#`, or `*`, and allows embedding specification for delay or pause between the output of individual digits.  # noqa: E501

        :param digits: The digits of this SendDigits.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and digits is None:  # noqa: E501
            raise ValueError("Invalid value for `digits`, must not be `None`")  # noqa: E501

        self._digits = digits

    @property
    def pause_ms(self):
        """Gets the pause_ms of this SendDigits.  # noqa: E501

        Pause between digits in milliseconds. Valid values are 100-1000 milliseconds and will be adjusted by FreeClimb to satisfy the constraint.  # noqa: E501

        :return: The pause_ms of this SendDigits.  # noqa: E501
        :rtype: int
        """
        return self._pause_ms

    @pause_ms.setter
    def pause_ms(self, pause_ms):
        """Sets the pause_ms of this SendDigits.

        Pause between digits in milliseconds. Valid values are 100-1000 milliseconds and will be adjusted by FreeClimb to satisfy the constraint.  # noqa: E501

        :param pause_ms: The pause_ms of this SendDigits.  # noqa: E501
        :type: int
        """

        self._pause_ms = pause_ms

    @property
    def privacy_mode(self):
        """Gets the privacy_mode of this SendDigits.  # noqa: E501

        Parameter `privacyMode` will not log the `text` as required by PCI compliance.  # noqa: E501

        :return: The privacy_mode of this SendDigits.  # noqa: E501
        :rtype: bool
        """
        return self._privacy_mode

    @privacy_mode.setter
    def privacy_mode(self, privacy_mode):
        """Sets the privacy_mode of this SendDigits.

        Parameter `privacyMode` will not log the `text` as required by PCI compliance.  # noqa: E501

        :param privacy_mode: The privacy_mode of this SendDigits.  # noqa: E501
        :type: bool
        """

        self._privacy_mode = privacy_mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.to_camel_case(attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif value is None:
                continue
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SendDigits):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SendDigits):
            return True

        return self.to_dict() != other.to_dict()

    def to_camel_case(self, snake_str):
        components = snake_str.split('_')
        return components[0] + ''.join(x.title() for x in components[1:])



# coding: utf-8

# flake8: noqa
"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from freeclimb.models.account_request import AccountRequest
from freeclimb.models.account_result import AccountResult
from freeclimb.models.account_result_all_of import AccountResultAllOf
from freeclimb.models.add_to_conference import AddToConference
from freeclimb.models.add_to_conference_all_of import AddToConferenceAllOf
from freeclimb.models.application_list import ApplicationList
from freeclimb.models.application_list_all_of import ApplicationListAllOf
from freeclimb.models.application_request import ApplicationRequest
from freeclimb.models.application_result import ApplicationResult
from freeclimb.models.application_result_all_of import ApplicationResultAllOf
from freeclimb.models.available_number import AvailableNumber
from freeclimb.models.available_number_list import AvailableNumberList
from freeclimb.models.available_number_list_all_of import AvailableNumberListAllOf
from freeclimb.models.buy_incoming_number_request import BuyIncomingNumberRequest
from freeclimb.models.call_list import CallList
from freeclimb.models.call_list_all_of import CallListAllOf
from freeclimb.models.call_result import CallResult
from freeclimb.models.call_result_all_of import CallResultAllOf
from freeclimb.models.conference_list import ConferenceList
from freeclimb.models.conference_list_all_of import ConferenceListAllOf
from freeclimb.models.conference_participant_list import ConferenceParticipantList
from freeclimb.models.conference_participant_list_all_of import ConferenceParticipantListAllOf
from freeclimb.models.conference_participant_result import ConferenceParticipantResult
from freeclimb.models.conference_participant_result_all_of import ConferenceParticipantResultAllOf
from freeclimb.models.conference_result import ConferenceResult
from freeclimb.models.conference_result_all_of import ConferenceResultAllOf
from freeclimb.models.create_conference import CreateConference
from freeclimb.models.create_conference_all_of import CreateConferenceAllOf
from freeclimb.models.create_conference_request import CreateConferenceRequest
from freeclimb.models.dequeue import Dequeue
from freeclimb.models.enqueue import Enqueue
from freeclimb.models.enqueue_all_of import EnqueueAllOf
from freeclimb.models.filter_logs_request import FilterLogsRequest
from freeclimb.models.get_digits import GetDigits
from freeclimb.models.get_digits_all_of import GetDigitsAllOf
from freeclimb.models.get_speech import GetSpeech
from freeclimb.models.get_speech_all_of import GetSpeechAllOf
from freeclimb.models.hangup import Hangup
from freeclimb.models.hangup_all_of import HangupAllOf
from freeclimb.models.incoming_number_list import IncomingNumberList
from freeclimb.models.incoming_number_list_all_of import IncomingNumberListAllOf
from freeclimb.models.incoming_number_request import IncomingNumberRequest
from freeclimb.models.incoming_number_result import IncomingNumberResult
from freeclimb.models.incoming_number_result_all_of import IncomingNumberResultAllOf
from freeclimb.models.log_list import LogList
from freeclimb.models.log_list_all_of import LogListAllOf
from freeclimb.models.log_result import LogResult
from freeclimb.models.make_call_request import MakeCallRequest
from freeclimb.models.message_request import MessageRequest
from freeclimb.models.message_request_all_of import MessageRequestAllOf
from freeclimb.models.message_result import MessageResult
from freeclimb.models.message_result_all_of import MessageResultAllOf
from freeclimb.models.messages_list import MessagesList
from freeclimb.models.messages_list_all_of import MessagesListAllOf
from freeclimb.models.mutable_resource_model import MutableResourceModel
from freeclimb.models.out_dial import OutDial
from freeclimb.models.out_dial_all_of import OutDialAllOf
from freeclimb.models.pagination_model import PaginationModel
from freeclimb.models.pause import Pause
from freeclimb.models.pause_all_of import PauseAllOf
from freeclimb.models.percl_command import PerclCommand
from freeclimb.models.percl_script import PerclScript
from freeclimb.models.play import Play
from freeclimb.models.play_all_of import PlayAllOf
from freeclimb.models.play_early_media import PlayEarlyMedia
from freeclimb.models.play_early_media_all_of import PlayEarlyMediaAllOf
from freeclimb.models.queue_list import QueueList
from freeclimb.models.queue_list_all_of import QueueListAllOf
from freeclimb.models.queue_member import QueueMember
from freeclimb.models.queue_member_list import QueueMemberList
from freeclimb.models.queue_member_list_all_of import QueueMemberListAllOf
from freeclimb.models.queue_request import QueueRequest
from freeclimb.models.queue_result import QueueResult
from freeclimb.models.queue_result_all_of import QueueResultAllOf
from freeclimb.models.record_utterance import RecordUtterance
from freeclimb.models.record_utterance_all_of import RecordUtteranceAllOf
from freeclimb.models.recording_list import RecordingList
from freeclimb.models.recording_list_all_of import RecordingListAllOf
from freeclimb.models.recording_result import RecordingResult
from freeclimb.models.recording_result_all_of import RecordingResultAllOf
from freeclimb.models.redirect import Redirect
from freeclimb.models.redirect_all_of import RedirectAllOf
from freeclimb.models.reject import Reject
from freeclimb.models.reject_all_of import RejectAllOf
from freeclimb.models.remove_from_conference import RemoveFromConference
from freeclimb.models.remove_from_conference_all_of import RemoveFromConferenceAllOf
from freeclimb.models.say import Say
from freeclimb.models.say_all_of import SayAllOf
from freeclimb.models.send_digits import SendDigits
from freeclimb.models.send_digits_all_of import SendDigitsAllOf
from freeclimb.models.set_listen import SetListen
from freeclimb.models.set_listen_all_of import SetListenAllOf
from freeclimb.models.set_talk import SetTalk
from freeclimb.models.set_talk_all_of import SetTalkAllOf
from freeclimb.models.sms import Sms
from freeclimb.models.sms_all_of import SmsAllOf
from freeclimb.models.start_record_call import StartRecordCall
from freeclimb.models.terminate_conference import TerminateConference
from freeclimb.models.terminate_conference_all_of import TerminateConferenceAllOf
from freeclimb.models.update_call_request import UpdateCallRequest
from freeclimb.models.update_conference_participant_request import UpdateConferenceParticipantRequest
from freeclimb.models.update_conference_request import UpdateConferenceRequest



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from freeclimb.configuration import Configuration


class ConferenceResultAllOf(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'conference_id': 'str',
        'account_id': 'str',
        'alias': 'str',
        'play_beep': 'str',
        'record': 'bool',
        'status': 'str',
        'wait_url': 'str',
        'action_url': 'str',
        'status_callback_url': 'str',
        'subresource_uris': 'object'
    }

    attribute_map = {
        'conference_id': 'conferenceId',
        'account_id': 'accountId',
        'alias': 'alias',
        'play_beep': 'playBeep',
        'record': 'record',
        'status': 'status',
        'wait_url': 'waitUrl',
        'action_url': 'actionUrl',
        'status_callback_url': 'statusCallbackUrl',
        'subresource_uris': 'subresourceUris'
    }

    def __init__(self, conference_id=None, account_id=None, alias=None, play_beep=None, record=None, status=None, wait_url=None, action_url=None, status_callback_url=None, subresource_uris=None, local_vars_configuration=None):  # noqa: E501
        """ConferenceResultAllOf - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._conference_id = None
        self._account_id = None
        self._alias = None
        self._play_beep = None
        self._record = None
        self._status = None
        self._wait_url = None
        self._action_url = None
        self._status_callback_url = None
        self._subresource_uris = None
        self.discriminator = None

        if conference_id is not None:
            self.conference_id = conference_id
        if account_id is not None:
            self.account_id = account_id
        if alias is not None:
            self.alias = alias
        if play_beep is not None:
            self.play_beep = play_beep
        if record is not None:
            self.record = record
        if status is not None:
            self.status = status
        if wait_url is not None:
            self.wait_url = wait_url
        if action_url is not None:
            self.action_url = action_url
        if status_callback_url is not None:
            self.status_callback_url = status_callback_url
        if subresource_uris is not None:
            self.subresource_uris = subresource_uris

    @property
    def conference_id(self):
        """Gets the conference_id of this ConferenceResultAllOf.  # noqa: E501

        A string that uniquely identifies this Conference resource.  # noqa: E501

        :return: The conference_id of this ConferenceResultAllOf.  # noqa: E501
        :rtype: str
        """
        return self._conference_id

    @conference_id.setter
    def conference_id(self, conference_id):
        """Sets the conference_id of this ConferenceResultAllOf.

        A string that uniquely identifies this Conference resource.  # noqa: E501

        :param conference_id: The conference_id of this ConferenceResultAllOf.  # noqa: E501
        :type: str
        """

        self._conference_id = conference_id

    @property
    def account_id(self):
        """Gets the account_id of this ConferenceResultAllOf.  # noqa: E501

        ID of the account that created this Conference.  # noqa: E501

        :return: The account_id of this ConferenceResultAllOf.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this ConferenceResultAllOf.

        ID of the account that created this Conference.  # noqa: E501

        :param account_id: The account_id of this ConferenceResultAllOf.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def alias(self):
        """Gets the alias of this ConferenceResultAllOf.  # noqa: E501

        A description for this Conference.  # noqa: E501

        :return: The alias of this ConferenceResultAllOf.  # noqa: E501
        :rtype: str
        """
        return self._alias

    @alias.setter
    def alias(self, alias):
        """Sets the alias of this ConferenceResultAllOf.

        A description for this Conference.  # noqa: E501

        :param alias: The alias of this ConferenceResultAllOf.  # noqa: E501
        :type: str
        """

        self._alias = alias

    @property
    def play_beep(self):
        """Gets the play_beep of this ConferenceResultAllOf.  # noqa: E501

        Setting that controls when a beep is played. One of: always, never, entryOnly, exitOnly. Defaults to always.  # noqa: E501

        :return: The play_beep of this ConferenceResultAllOf.  # noqa: E501
        :rtype: str
        """
        return self._play_beep

    @play_beep.setter
    def play_beep(self, play_beep):
        """Sets the play_beep of this ConferenceResultAllOf.

        Setting that controls when a beep is played. One of: always, never, entryOnly, exitOnly. Defaults to always.  # noqa: E501

        :param play_beep: The play_beep of this ConferenceResultAllOf.  # noqa: E501
        :type: str
        """
        allowed_values = ["always", "never", "entryOnly", "exitOnly"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and play_beep not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `play_beep` ({0}), must be one of {1}"  # noqa: E501
                .format(play_beep, allowed_values)
            )

        self._play_beep = play_beep

    @property
    def record(self):
        """Gets the record of this ConferenceResultAllOf.  # noqa: E501

        Flag indicating whether recording is enabled for this Conference.  # noqa: E501

        :return: The record of this ConferenceResultAllOf.  # noqa: E501
        :rtype: bool
        """
        return self._record

    @record.setter
    def record(self, record):
        """Sets the record of this ConferenceResultAllOf.

        Flag indicating whether recording is enabled for this Conference.  # noqa: E501

        :param record: The record of this ConferenceResultAllOf.  # noqa: E501
        :type: bool
        """

        self._record = record

    @property
    def status(self):
        """Gets the status of this ConferenceResultAllOf.  # noqa: E501

        The status of the Conference. One of: creating, empty, populated, inProgress, or terminated.  # noqa: E501

        :return: The status of this ConferenceResultAllOf.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ConferenceResultAllOf.

        The status of the Conference. One of: creating, empty, populated, inProgress, or terminated.  # noqa: E501

        :param status: The status of this ConferenceResultAllOf.  # noqa: E501
        :type: str
        """
        allowed_values = ["creating", "empty", "populated", "inProgress", "terminated"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def wait_url(self):
        """Gets the wait_url of this ConferenceResultAllOf.  # noqa: E501

        URL referencing the audio file to be used as default wait music for the Conference when it is in the populated state.  # noqa: E501

        :return: The wait_url of this ConferenceResultAllOf.  # noqa: E501
        :rtype: str
        """
        return self._wait_url

    @wait_url.setter
    def wait_url(self, wait_url):
        """Sets the wait_url of this ConferenceResultAllOf.

        URL referencing the audio file to be used as default wait music for the Conference when it is in the populated state.  # noqa: E501

        :param wait_url: The wait_url of this ConferenceResultAllOf.  # noqa: E501
        :type: str
        """

        self._wait_url = wait_url

    @property
    def action_url(self):
        """Gets the action_url of this ConferenceResultAllOf.  # noqa: E501

        URL invoked once the Conference is successfully created.  # noqa: E501

        :return: The action_url of this ConferenceResultAllOf.  # noqa: E501
        :rtype: str
        """
        return self._action_url

    @action_url.setter
    def action_url(self, action_url):
        """Sets the action_url of this ConferenceResultAllOf.

        URL invoked once the Conference is successfully created.  # noqa: E501

        :param action_url: The action_url of this ConferenceResultAllOf.  # noqa: E501
        :type: str
        """

        self._action_url = action_url

    @property
    def status_callback_url(self):
        """Gets the status_callback_url of this ConferenceResultAllOf.  # noqa: E501

        URL to inform that the Conference status has changed.  # noqa: E501

        :return: The status_callback_url of this ConferenceResultAllOf.  # noqa: E501
        :rtype: str
        """
        return self._status_callback_url

    @status_callback_url.setter
    def status_callback_url(self, status_callback_url):
        """Sets the status_callback_url of this ConferenceResultAllOf.

        URL to inform that the Conference status has changed.  # noqa: E501

        :param status_callback_url: The status_callback_url of this ConferenceResultAllOf.  # noqa: E501
        :type: str
        """

        self._status_callback_url = status_callback_url

    @property
    def subresource_uris(self):
        """Gets the subresource_uris of this ConferenceResultAllOf.  # noqa: E501

        The list of subresources for this Conference. This includes participants and/or recordings.  # noqa: E501

        :return: The subresource_uris of this ConferenceResultAllOf.  # noqa: E501
        :rtype: object
        """
        return self._subresource_uris

    @subresource_uris.setter
    def subresource_uris(self, subresource_uris):
        """Sets the subresource_uris of this ConferenceResultAllOf.

        The list of subresources for this Conference. This includes participants and/or recordings.  # noqa: E501

        :param subresource_uris: The subresource_uris of this ConferenceResultAllOf.  # noqa: E501
        :type: object
        """

        self._subresource_uris = subresource_uris

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.to_camel_case(attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif value is None:
                continue
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConferenceResultAllOf):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ConferenceResultAllOf):
            return True

        return self.to_dict() != other.to_dict()

    def to_camel_case(self, snake_str):
        components = snake_str.split('_')
        return components[0] + ''.join(x.title() for x in components[1:])



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from freeclimb.configuration import Configuration


class MessageResultAllOf(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'str',
        'message_id': 'str',
        'status': 'str',
        '_from': 'str',
        'to': 'str',
        'text': 'str',
        'direction': 'str',
        'notification_url': 'str'
    }

    attribute_map = {
        'account_id': 'accountId',
        'message_id': 'messageId',
        'status': 'status',
        '_from': 'from',
        'to': 'to',
        'text': 'text',
        'direction': 'direction',
        'notification_url': 'notificationUrl'
    }

    def __init__(self, account_id=None, message_id=None, status=None, _from=None, to=None, text=None, direction=None, notification_url=None, local_vars_configuration=None):  # noqa: E501
        """MessageResultAllOf - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._message_id = None
        self._status = None
        self.__from = None
        self._to = None
        self._text = None
        self._direction = None
        self._notification_url = None
        self.discriminator = None

        if account_id is not None:
            self.account_id = account_id
        if message_id is not None:
            self.message_id = message_id
        if status is not None:
            self.status = status
        if _from is not None:
            self._from = _from
        if to is not None:
            self.to = to
        if text is not None:
            self.text = text
        if direction is not None:
            self.direction = direction
        if notification_url is not None:
            self.notification_url = notification_url

    @property
    def account_id(self):
        """Gets the account_id of this MessageResultAllOf.  # noqa: E501

        String that uniquely identifies this account resource.  # noqa: E501

        :return: The account_id of this MessageResultAllOf.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this MessageResultAllOf.

        String that uniquely identifies this account resource.  # noqa: E501

        :param account_id: The account_id of this MessageResultAllOf.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def message_id(self):
        """Gets the message_id of this MessageResultAllOf.  # noqa: E501

        String that uniquely identifies this message resource  # noqa: E501

        :return: The message_id of this MessageResultAllOf.  # noqa: E501
        :rtype: str
        """
        return self._message_id

    @message_id.setter
    def message_id(self, message_id):
        """Sets the message_id of this MessageResultAllOf.

        String that uniquely identifies this message resource  # noqa: E501

        :param message_id: The message_id of this MessageResultAllOf.  # noqa: E501
        :type: str
        """

        self._message_id = message_id

    @property
    def status(self):
        """Gets the status of this MessageResultAllOf.  # noqa: E501

        Indicates the state of the message through the message lifecycle including: new, queued, rejected, sending, sent, failed, received, undelivered, expired, deleted, and unknown  # noqa: E501

        :return: The status of this MessageResultAllOf.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this MessageResultAllOf.

        Indicates the state of the message through the message lifecycle including: new, queued, rejected, sending, sent, failed, received, undelivered, expired, deleted, and unknown  # noqa: E501

        :param status: The status of this MessageResultAllOf.  # noqa: E501
        :type: str
        """
        allowed_values = ["new", "queued", "rejected", "sending", "sent", "failed", "received", "undelivered", "expired", "deleted", "unknown"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def _from(self):
        """Gets the _from of this MessageResultAllOf.  # noqa: E501

        Phone number in E.164 format that sent the message.  # noqa: E501

        :return: The _from of this MessageResultAllOf.  # noqa: E501
        :rtype: str
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this MessageResultAllOf.

        Phone number in E.164 format that sent the message.  # noqa: E501

        :param _from: The _from of this MessageResultAllOf.  # noqa: E501
        :type: str
        """

        self.__from = _from

    @property
    def to(self):
        """Gets the to of this MessageResultAllOf.  # noqa: E501

        Phone number in E.164 format that received the message.  # noqa: E501

        :return: The to of this MessageResultAllOf.  # noqa: E501
        :rtype: str
        """
        return self._to

    @to.setter
    def to(self, to):
        """Sets the to of this MessageResultAllOf.

        Phone number in E.164 format that received the message.  # noqa: E501

        :param to: The to of this MessageResultAllOf.  # noqa: E501
        :type: str
        """

        self._to = to

    @property
    def text(self):
        """Gets the text of this MessageResultAllOf.  # noqa: E501

        Message contents  # noqa: E501

        :return: The text of this MessageResultAllOf.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this MessageResultAllOf.

        Message contents  # noqa: E501

        :param text: The text of this MessageResultAllOf.  # noqa: E501
        :type: str
        """

        self._text = text

    @property
    def direction(self):
        """Gets the direction of this MessageResultAllOf.  # noqa: E501

        Noting whether the message was inbound or outbound  # noqa: E501

        :return: The direction of this MessageResultAllOf.  # noqa: E501
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """Sets the direction of this MessageResultAllOf.

        Noting whether the message was inbound or outbound  # noqa: E501

        :param direction: The direction of this MessageResultAllOf.  # noqa: E501
        :type: str
        """

        self._direction = direction

    @property
    def notification_url(self):
        """Gets the notification_url of this MessageResultAllOf.  # noqa: E501

        URL invoked when message sent  # noqa: E501

        :return: The notification_url of this MessageResultAllOf.  # noqa: E501
        :rtype: str
        """
        return self._notification_url

    @notification_url.setter
    def notification_url(self, notification_url):
        """Sets the notification_url of this MessageResultAllOf.

        URL invoked when message sent  # noqa: E501

        :param notification_url: The notification_url of this MessageResultAllOf.  # noqa: E501
        :type: str
        """

        self._notification_url = notification_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.to_camel_case(attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif value is None:
                continue
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MessageResultAllOf):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MessageResultAllOf):
            return True

        return self.to_dict() != other.to_dict()

    def to_camel_case(self, snake_str):
        components = snake_str.split('_')
        return components[0] + ''.join(x.title() for x in components[1:])
